@@ -4,8 +4,6 @@ from __future__ import annotations
 
 import logging
 import os
-import random
-import sys
 import time
 from argparse import Action, ArgumentError, ArgumentParser, Namespace
 from concurrent.futures import CancelledError, Future, ThreadPoolExecutor, as_completed
@@ -21,7 +19,6 @@ from tox.execute import Outcome
 from tox.journal import write_journal
 from tox.session.cmd.run.single import ToxEnvRunResult, run_one
 from tox.tox_env.runner import RunToxEnv
-from tox.util.ci import is_ci
 from tox.util.graph import stable_topological_sort
 from tox.util.spinner import MISS_DURATION, Spinner
 
@@ -62,17 +59,8 @@ class InstallPackageAction(Action):
         setattr(namespace, self.dest, path)
 
 
-def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C901
+def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:
     # mode can be one of: run, run-parallel, legacy, devenv, config
-    if mode not in {"config", "depends"}:
-        parser.add_argument(
-            "--result-json",
-            dest="result_json",
-            metavar="path",
-            of_type=Path,
-            default=None,
-            help="write a JSON file with detailed information about all commands and results involved",
-        )
     if mode not in {"devenv", "depends"}:
         parser.add_argument(
             "-s",
@@ -114,51 +102,6 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C9
             help="install package in development mode",
             dest="develop",
         )
-    if mode != "depends":
-
-        class SeedAction(Action):
-            def __call__(
-                self,
-                parser: ArgumentParser,  # noqa: ARG002
-                namespace: Namespace,
-                values: str | Sequence[Any] | None,
-                option_string: str | None = None,  # noqa: ARG002
-            ) -> None:
-                if values == "notset":
-                    result = None
-                else:
-                    try:
-                        result = int(cast(str, values))
-                        if result <= 0:
-                            msg = "must be greater than zero"
-                            raise ValueError(msg)  # noqa: TRY301
-                    except ValueError as exc:
-                        raise ArgumentError(self, str(exc)) from exc
-                setattr(namespace, self.dest, result)
-
-        if os.environ.get("PYTHONHASHSEED", "random") != "random":
-            hashseed_default = int(os.environ["PYTHONHASHSEED"])
-        else:
-            hashseed_default = random.randint(1, 1024 if sys.platform == "win32" else 4294967295)  # noqa: S311
-
-        parser.add_argument(
-            "--hashseed",
-            metavar="SEED",
-            help="set PYTHONHASHSEED to SEED before running commands. Defaults to a random integer in the range "
-            "[1, 4294967295] ([1, 1024] on Windows). Passing 'notset' suppresses this behavior.",
-            action=SeedAction,
-            of_type=Optional[int],
-            default=hashseed_default,
-            dest="hash_seed",
-        )
-    parser.add_argument(
-        "--discover",
-        dest="discover",
-        nargs="+",
-        metavar="path",
-        help="for Python discovery first try the Python executables under these paths",
-        default=[],
-    )
     if mode != "depends":
         parser.add_argument(
             "--no-recreate-pkg",
@@ -166,19 +109,6 @@ def env_run_create_flags(parser: ArgumentParser, mode: str) -> None:  # noqa: C9
             help="if recreate is set do not recreate packaging tox environment(s)",
             action="store_true",
         )
-        list_deps = parser.add_mutually_exclusive_group()
-        list_deps.add_argument(
-            "--list-dependencies",
-            action="store_true",
-            default=is_ci(),
-            help="list the dependencies installed during environment setup",
-        )
-        list_deps.add_argument(
-            "--no-list-dependencies",
-            action="store_false",
-            dest="list_dependencies",
-            help="never list the dependencies installed during environment setup",
-        )
     if mode not in {"devenv", "config", "depends"}:
         parser.add_argument(
             "--skip-pkg-install",
@@ -256,9 +186,9 @@ def execute(state: State, max_workers: int | None, has_spinner: bool, live: bool
             interrupt.set()
             # cancel in reverse order to not allow submitting new jobs as we cancel running ones
             for future, tox_env in reversed(list(future_to_env.items())):
-                cancelled = future.cancel()
-                # if cannot be cancelled and not done -> still runs
-                if cancelled is False and not future.done():  # pragma: no branch
+                canceled = future.cancel()
+                # if cannot be canceled and not done -> still runs
+                if canceled is False and not future.done():  # pragma: no branch
                     tox_env.interrupt()
             done.wait()
             # workaround for https://bugs.python.org/issue45274
@@ -299,7 +229,7 @@ class ToxSpinner(Spinner):
         done(result.name)
 
 
-def _queue_and_wait(  # noqa: C901, PLR0913, PLR0915
+def _queue_and_wait(  # noqa: C901, PLR0913, PLR0915, PLR0912
     state: State,
     to_run_list: list[str],
     results: list[ToxEnvRunResult],
@@ -310,7 +240,7 @@ def _queue_and_wait(  # noqa: C901, PLR0913, PLR0915
     spinner: ToxSpinner,
     live: bool,  # noqa: FBT001
 ) -> None:
-    try:
+    try:  # noqa: PLR1702
         options = state._options  # noqa: SLF001
         with spinner:
             max_workers = len(to_run_list) if max_workers is None else max_workers
