@@ -52,7 +52,7 @@ def _evaluate(tox_env: RunToxEnv, no_test: bool) -> tuple[bool, int, list[Outcom
             skipped = True
         except ToxBackendFailed as exception:
             LOGGER.error("%s", exception)  # noqa: TRY400
-            raise SystemExit(exception.code)  # noqa: B904, TRY200
+            raise SystemExit(exception.code)  # noqa: B904
         except Fail as exception:
             LOGGER.error("failed with %s", exception)  # noqa: TRY400
             code = 1
@@ -112,7 +112,10 @@ def run_command_set(
         )
         outcomes.append(current_outcome)
         try:
-            current_outcome.assert_success()
+            if cmd.invert_exit_code:
+                current_outcome.assert_failure()
+            else:
+                current_outcome.assert_success()
         except SystemExit as exception:
             if cmd.ignore_exit_code:
                 logging.warning("command failed but is marked ignore outcome so handling it as success")
@@ -126,7 +129,7 @@ def run_command_set(
 
 
 __all__ = (
-    "run_one",
-    "run_command_set",
     "ToxEnvRunResult",
+    "run_command_set",
+    "run_one",
 )
