@@ -3,6 +3,7 @@ from __future__ import annotations
 import logging
 import os
 import sys
+from abc import ABC
 from collections import defaultdict
 from contextlib import contextmanager
 from itertools import chain
@@ -56,13 +57,13 @@ ConfigSettings = Optional[Dict[str, Any]]
 
 class ToxBackendFailed(Fail, BackendFailed):
     def __init__(self, backend_failed: BackendFailed) -> None:
-        Fail.__init__(self)  # noqa: PLC2801
+        Fail.__init__(self)
         result: dict[str, Any] = {
             "code": backend_failed.code,
             "exc_type": backend_failed.exc_type,
             "exc_msg": backend_failed.exc_msg,
         }
-        BackendFailed.__init__(  # noqa: PLC2801
+        BackendFailed.__init__(
             self,
             result,
             backend_failed.out,
@@ -94,8 +95,8 @@ class ToxCmdStatus(CmdStatus):
         return status.outcome.out_err()
 
 
-class Pep517VirtualEnvPackager(PythonPackageToxEnv, VirtualEnv):
-    """local file system python virtual environment via the virtualenv package."""
+class Pep517VenvPackager(PythonPackageToxEnv, ABC):
+    """local file system python virtual environment package builder."""
 
     def __init__(self, create_args: ToxEnvCreateArgs) -> None:
         super().__init__(create_args)
@@ -106,8 +107,19 @@ class Pep517VirtualEnvPackager(PythonPackageToxEnv, VirtualEnv):
         self._package_dependencies: list[Requirement] | None = None
         self._package_name: str | None = None
         self._pkg_lock = RLock()  # can build only one package at a time
-        self.root = self.conf["package_root"]
         self._package_paths: set[Path] = set()
+        self._root: Path | None = None
+
+    @property
+    def root(self) -> Path:
+        if self._root is None:
+            self._root = self.conf["package_root"]
+        return self._root
+
+    @root.setter
+    def root(self, value: Path) -> None:
+        self._root = value
+        self._frontend_ = None  # force recreating the frontend with new root
 
     @staticmethod
     def id() -> str:
@@ -135,6 +147,12 @@ class Pep517VirtualEnvPackager(PythonPackageToxEnv, VirtualEnv):
         )
         for key in ("sdist", "wheel", "editable"):
             self._add_config_settings(key)
+        self.conf.add_config(
+            keys=["fresh_subprocess"],
+            of_type=bool,
+            default=self._frontend.backend.split(".")[0] == "setuptools",
+            desc="create a fresh subprocess for every backend request",
+        )
 
     def _add_config_settings(self, build_type: str) -> None:
         # config settings passed to PEP-517-compliant build backend https://peps.python.org/pep-0517/#config-settings
@@ -360,8 +378,16 @@ class Pep517VirtualEnvPackager(PythonPackageToxEnv, VirtualEnv):
         return self._frontend.requires
 
 
+class Pep517VirtualEnvPackager(Pep517VenvPackager, VirtualEnv):
+    """local file system python virtual environment via the virtualenv package."""
+
+    @staticmethod
+    def id() -> str:
+        return "virtualenv-pep-517"
+
+
 class Pep517VirtualEnvFrontend(Frontend):
-    def __init__(self, root: Path, env: Pep517VirtualEnvPackager) -> None:
+    def __init__(self, root: Path, env: Pep517VenvPackager) -> None:
         super().__init__(*Frontend.create_args_from_folder(root))
         self._tox_env = env
         self._backend_executor_: LocalSubProcessPep517Executor | None = None
@@ -403,21 +429,25 @@ class Pep517VirtualEnvFrontend(Frontend):
         result_file: Path,  # noqa: ARG002
         msg: str,
     ) -> Iterator[ToxCmdStatus]:
-        with self._tox_env.execute_async(
-            cmd=self.backend_cmd,
-            cwd=self._root,
-            stdin=StdinSource.API,
-            show=None,
-            run_id=cmd,
-            executor=self.backend_executor,
-        ) as execute_status:
-            execute_status.write_stdin(f"{msg}{os.linesep}")
-            yield ToxCmdStatus(execute_status)
-        outcome = execute_status.outcome
-        if outcome is not None:  # pragma: no branch
-            outcome.assert_success()
+        try:
+            with self._tox_env.execute_async(
+                cmd=self.backend_cmd,
+                cwd=self._root,
+                stdin=StdinSource.API,
+                show=None,
+                run_id=cmd,
+                executor=self.backend_executor,
+            ) as execute_status:
+                execute_status.write_stdin(f"{msg}{os.linesep}")
+                yield ToxCmdStatus(execute_status)
+            outcome = execute_status.outcome
+            if outcome is not None:  # pragma: no branch
+                outcome.assert_success()
+        finally:
+            if self._tox_env.conf["fresh_subprocess"]:
+                self.backend_executor.close()
 
-    def _unexpected_response(  # noqa: PLR0913
+    def _unexpected_response(
         self,
         cmd: str,
         got: Any,
@@ -454,3 +484,9 @@ class Pep517VirtualEnvFrontend(Frontend):
 @impl
 def tox_register_tox_env(register: ToxEnvRegister) -> None:
     register.add_package_env(Pep517VirtualEnvPackager)
+
+
+__all__ = [
+    "Pep517VenvPackager",
+    "Pep517VirtualEnvPackager",
+]
